==> faq-system-0.3.1.tar.gz: faq-system-0.3.1/index.cc <==
#include "conf.h"
#include <fstream.h>
int main(void)
{
	int i;
	char **tuple;
	Database *db;
	DBResult *res;
	HTML h;
	cgi C;
	C.initPage();
	string instance;
	instance = C.get_value("instance");
	config CONF(instance);

	const char* MYDATABASE;
	const char* MYTOPIC;
	const char* MYANSWER;
	const char* MYQUESTION;

	MYDATABASE = CONF.MYDATABASE.c_str();
	MYTOPIC = CONF.MYTOPIC.c_str();
	MYANSWER = CONF.MYANSWER.c_str();
	MYQUESTION = CONF.MYQUESTION.c_str();

	string format;	
	if(CONF.FORMAT == "large")
	{	
		format = "large";
	}
	else
	{	
		format = "topic";
	}


	// we check for valid values in class config! 
	// we maybe here at the last point of the program!

	db = new Database();

	// Initialise the database - for future releases
	if (db->init() != DB_COMMAND_OK) {
		fprintf(stdout, "Unable to initialize database: %s\n\n", 
		        db->errorMessage());
		exit(1);
        }

	// Connect to database on localhost
	if (db->connect("localhost", "", MYDATABASE) != DB_CONNECTION_OK) {
		fprintf(stdout, "Unable connect to database '%s': %s\n\n", 
		        MYDATABASE, db->errorMessage());
		exit(1);
	}

	int topic_max = 0, question_max;
	string *tmp, *question_id, *question; 
	tmp = new string[10];
	string temp;
	int answer_max;
	// determine the numer of rows in topic...	
	res = db->exec("SELECT topic_id FROM %s ", MYTOPIC);
	tuple = res->getTuple();
	while (tuple != NULL)
	{
		topic_max++;
		tuple = res->getTuple();
	}

	string topic[topic_max + 1];
	int topic_id[topic_max + 1];
	string topic_id_str[topic_max + 1];
	
	// now get the real topic_id's
	db->exec(res, "SELECT topic_id FROM %s ", MYTOPIC);
        tuple = res->getTuple();
	i=0;
        while (tuple != NULL)
        {
                topic_id[i] = atoi(*(tuple));
		topic_id_str[i] = *(tuple);
                tuple = res->getTuple();
		i++;
        }
	
	// get the related topics...
	db->exec(res, "SELECT value FROM %s ", MYTOPIC);
        tuple = res->getTuple();
        i = 0;
	while (tuple != NULL)
        {
                topic[i] = *(tuple);
                tuple = res->getTuple();
		i++;
        }
	string Head, Foot, Index_Temp_f, Index_Header_f, Index_Footer_f;
	string Store_answer[20], topic_f, anchor;
	char ch;
	Index_Header_f = string(PATH) + "/" + string(HEADER);
	Index_Footer_f = string(PATH) + "/" + string(FOOTER);
	Index_Temp_f = string(PATH) + "/temp.html"; 
	ofstream Index_Temp(Index_Temp_f.c_str());
	ifstream Header_File(Index_Header_f.c_str());
	ifstream Footer_File(Index_Footer_f.c_str());
	if( !Header_File )
	{
		Head = h.html() + h.body("#ffffff", "#000000", "#3333FF", "#3333FF", "#FF0000");
		Head += h.title("Database Full Index") + "<p></p>\n";
	}
	else
	{
		while( Header_File )
		{
			Header_File.get(ch);
			Head += ch;
		}
	}
	if( !Footer_File )
	{
		Foot = "created by faq-system " + string(VERSION); 
		Foot += " <a href=mailto:" + string(AUTOR_MAIL) + ">" + string(AUTOR) + "</a>" + h._body() + h._html() + "\n";
	}
	else
	{
		while( Footer_File )
		{ 
			Footer_File.get(ch);
			Foot += ch;
		}
	}
	// ################ fullindex.html ########################
        string Index_Name = string(PATH) + "/" + instance + ".html";
        ofstream Index(Index_Name.c_str());
	Index << Head;
	Index << "<a name=\"top\"></a>\n";
	Index << "<h2>Table of Contents</h2>\n";
	Index << "<p><hr></p>";
	

	cout << h.html()
		<< h.body("#ffffff", "#000000", "#3333FF", "#3333FF", "#FF0000");
	cout    << "<p>" << h.font("arial", "2");
	cout	<< "<A HREF=\"" << URL << "/" << ADMIN << "/index.cgi?instance=" << instance << "\">[ reload site ]</A> ";
	cout << "<A HREF=\"" << URL << "/search.cgi?instance=" << instance << "&stage=prepare\">[ search ]</A> ";
	cout << "<A HREF=\"" << HTTP_BASE << "/" << instance << ".html\">[ full index ]</A> ";
	cout << "<A HREF=\"" << HTTP_BASE << "/" ADMIN << "/help.html\">[ help ]</A> ";
	cout  << "</p>" << h._font(); 
	cout	<< "<p>" << h.font("arial", "+2"); 
	cout	<< "<b>  Topics  </b>" <<  h._font();
	cout	<< h.font("arial", "1") ;
	cout	<< "&nbsp;&nbsp;<A HREF=\"" << URL << "/" << ADMIN << "/topic.cgi?instance=" << instance; 
	cout	<< "&stage=prepare\">[ new topic ]</A></p>" << endl;
	for(int t=0;t<topic_max;t++)
	{
	if(format == "large")
	{
		// create an Index Entry
		Index << "<b>" << topic_id[t] << ". " << topic[t] << "</b><br>\n<ul>\n";
	}
	else
    	{
		// create one file per topic...
		Index << "<a href=\"" << instance << "_topic_" << topic_id[t] << ".html\"><b>" 
		<< topic_id[t] << ". " << topic[t] << "</b></a><br>\n<ul>\n";
	}
		topic_f = string(PATH) + "/" + instance + "_topic_" + topic_id_str[t] + ".html";
		ofstream topic_file(topic_f.c_str());
	if(format == "topic")
	{
		topic_file << Head;
		topic_file << "<a name=\"top\"></a>\n";
		topic_file << "<a href=\"" << instance << ".html\">[ top ]</a> ";
		if(t == 0)
		{
			topic_file << "<a href=\"" << instance << "_topic_" << topic_id[t+1] << ".html\">[ next ]</a> ";
		}
		else if(t == topic_max)
		{
			topic_file << "<a href=\"" << instance << "_topic_" << topic_id[t-1] << ".html\">[ previous ]</a> ";	
		}
		else
		{
			topic_file << "<a href=\"" << instance << "_topic_" << topic_id[t-1] << ".html\">[ previous ]</a> ";
			topic_file << "<a href=\"" << instance << "_topic_" << topic_id[t+1] << ".html\">[ next ]</a> ";
		}
		topic_file << "\n<br></br><h1>" << topic[t] << "</h1><br></br>\n";
	 
	}		
		
		cout 	<< "<p><b>" << h.font("arial", "3") << topic_id[t] << ". "; 
		cout	<< topic[t] << h._font();
		cout	<< h.font("arial", "1") << "&nbsp;&nbsp;<A HREF=\"" << URL ;
		cout	<< "/" << ADMIN << "/question.cgi?instance=" << instance << "&stage=prepare&topic_id="; 
		cout	<< topic_id[t] << "\">[ ask ]</A> "; 
		cout	<< "<A HREF=\"" << URL << "/" << ADMIN << "/modify.cgi?instance=" << instance 
			<< "&stage=prepare&mode=topic&topic_id="; 
		cout 	<< topic_id[t] << "\">[ modify ]</A>" << h._font(); 
		cout	<< h._font();
		cout	<< "</b></p>\n";
		db->exec(res, "SELECT question_id FROM %s WHERE topic_id = %d", MYQUESTION, topic_id[t]);
        	tuple = res->getTuple();
		question_max = 0;
       		while (tuple != NULL)
        	{
                       	question_max++; 
                	tuple = res->getTuple();
		}
		//cout << "debug IV\n";	
		question = new string[question_max];
		question_id = new string[question_max];

		db->exec(res, "SELECT value FROM %s WHERE topic_id = %d ", MYQUESTION, topic_id[t]);
                tuple = res->getTuple();
		i=0;
                while (tuple != NULL)
                {
                        question[i] = *(tuple);
			tuple = res->getTuple();
			i++;
                }
		db->exec(res, "SELECT question_id FROM %s WHERE topic_id = %d ", MYQUESTION, topic_id[t]);
                tuple = res->getTuple();
		i=0;
                while (tuple != NULL)
                {
			question_id[i] = *(tuple);
                        tuple = res->getTuple();
                        i++;
                }	

		for(int b=0; b<question_max; b++)
		{
			db->exec(res, "SELECT value FROM %s WHERE question_id = %s", MYANSWER, question_id[b].c_str());
			tuple = res->getTuple();
			answer_max = 0;
			while (tuple != NULL)	
			{
				if( *(tuple) == NULL)
				{
					answer_max=0;
					break;
				}
				answer_max++;
				tuple = res->getTuple();
			}

			cout << h.font("arial", "2") << endl; 
			cout << "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
			if( answer_max != 0 )
			{
				// create anchor name
				i=0;
				db->exec(res, "SELECT value FROM %s WHERE question_id = %s", MYANSWER, question_id[b].c_str());
                                tuple = res->getTuple();
				int p;
				string produce, store, link, caption;
				//char *link, *caption;
				//link = new char[250];
				//caption = new char[250];
				while (tuple != NULL)
                                {
                                        temp = *(tuple);
					int length = temp.length();
					for(int pos=0; pos<length;pos++)
					{
						if(temp[pos] == '#')
						{
							if(temp[pos+1] == '#')
							{
								pos += 2;
								p=0;
								while(temp[pos] != '#')
								{
									link += temp[pos];
									p++;
									pos++;
								} 
								pos++;
								p=0;
								while(temp[pos] != '#')
								{
									caption += temp[pos];
									p++;
									pos++;
								}
								store += "<a href=\"";
								if(link[0] == '_')
								{
									string topic_link;
									int topic_link_pos = 0;
									int topic_link_len = link.length();
									for(int p=0;p<topic_link_len;p++)
									{
										if(link[p] == '_')
										{
											if(topic_link_pos == 0)
												topic_link_pos++;
										}
										else
										{
											if(topic_link_pos == 1)
											{		
												topic_link += link[p];
												if(link[p+1] == '_')
													topic_link_pos++;
											}
										}
									}		
									store += string(HTTP_BASE) + "/";
		  							if(format == "large")
										store += instance + ".html#";
  									else
										//store += instance + "_topic_" + topic_id_str[t] + ".html#";
										store += instance + "_topic_" + topic_link + ".html#";
 
								}
								store += link + "\">" + caption + "</a>";
								link = "";
								caption = "";	
							}
							else
								store += temp[pos];
						}
						else
						{
							store += temp[pos];
						}
					}
					Store_answer[i] = store;
					store = "";	                        		 
                                        tuple = res->getTuple();
                                        i++;
                                } 
				Index << "<li>"; 
				if(format == "large")
				{
					Index << "<a href=\"#_" << topic_id[t] << "_" << b
					<< "\">" << topic_id[t] << "." << b << ". " << question[b] << "</a><br>\n";				
					Index_Temp << "<a name=\"_" << topic_id[t] << "_" << b  << "\"></a>\n";
					Index_Temp << "<h3>" << topic_id[t] << "." << b << ". " << question[b] << "</h3>\n";
					// here comes the answer:
					for(int m=0;m<i;m++)
					{
						Index_Temp << Store_answer[m].c_str() << "<br></br>\n";
					}
					Index_Temp << endl << "<br>" << h.font("arial", "1") 
					<< "<br></br><p><a href=\"#top\">[ top ]</a></p>"
					<< h._font() <<"<p></p><hr><p></p><br>" << endl;
				}
				else
				{
					Index << "<a href=\"" << instance << "_topic_" << topic_id[t] << ".html#_"
					<< topic_id[t] << "_" << b 
					<< "\">" << topic_id[t] << "." << b << ". " << question[b] << "</a><br>\n";	
					topic_file << "<a name=\"_" << topic_id[t] << "_" << b  << "\"></a>\n";
					topic_file << "<h3>" << topic_id[t] << "." << b << ". " << question[b] << "</h3>\n";
					// here comes the answer:
					for(int m=0;m<i;m++)
					{
						topic_file << Store_answer[m].c_str() << "<br></br>\n";
					} 
					topic_file << h.font("arial", "1") << "<br></br><p><a href=\"#top\">[ top ]</a></p>"
					<< h._font() << "<p></p><hr><p></p>\n";
				}
				cout << "<A HREF=\"" << URL 
 				<< "/getanswer.cgi?instance=" << instance << "&stage=dbadmin&question_id=";  
				cout << question_id[b] << "\">" << topic_id[t] << "." << b << ". ";
				cout << "<b>" << question[b] << "</b>";
				cout << "</A><b>" << h.font("arial","1") 
				<< " [[ _" << topic_id[t] << "_" << b << " ]]" << h._font() << "</b>";
				cout << "</A>";
			}
			else
			{

				cout << topic_id[t] << "." << b << ". ";
				cout << "<b>" << question[b] << "</b>";
			}

			cout << h._font();
			cout << h.font("arial","1") << "&nbsp;&nbsp;<A HREF=\"" << URL 
			<< "/" << ADMIN << "/answer.cgi?instance=" << instance << "&stage=prepare&question_id=";
			cout << question_id[b] << "&topic_id=" << topic_id[t];
			cout << "\">[ answer ]</A> ";
			cout << " <A HREF=\"" << URL << "/" << ADMIN << "/modify.cgi?instance=" << instance 
				<< "&stage=prepare&mode=question&question_id=";
			cout << question_id[b] << "&topic_id=" << topic_id[t];
			cout << "\">[ modify ]</A>" << h._font();
			cout << "<br>" << endl; 
		} 
		Index << "</ul>\n";
		topic_file << "</ul>\n"; 
		if(format == "topic")
			topic_file << Foot;
			
		cout << "<P></P><br></br>";		
	}
	if(format == "large")
	{
		Index << "<p></p><p></p><hr><p></p><p></p>\n";
		char buffer[1000];
		ifstream f(Index_Temp_f.c_str());
		while ( f )
		{
			f.getline(buffer, 1000);
			Index << buffer << "\n";
		}
		Index << Foot;	
	}
	
	delete res;			// Drop buffer
	delete db;			// Close connection
}

==> faq-system-0.3.2.tar.gz: faq-system-0.3.2/index.cc <==
#include "conf.h"
#include <fstream.h>
int main(void)
{
	int i;
	char **tuple;
	Database *db;
	DBResult *res;
	HTML h;
	cgi C;
	C.initPage();
	string instance;
	instance = C.get_value("instance");
//	instance = "faq";
	config CONF(instance);

	const char* MYDATABASE;
	const char* MYTOPIC;
	const char* MYANSWER;
	const char* MYQUESTION;
        const char* USER;
        const char* PASS;
        const char* HOST;
	HOST = CONF.HOST.c_str();
        USER = CONF.USER.c_str();
        PASS = CONF.PASS.c_str(); 
	MYDATABASE = CONF.MYDATABASE.c_str();
	MYTOPIC = CONF.MYTOPIC.c_str();
	MYANSWER = CONF.MYANSWER.c_str();
	MYQUESTION = CONF.MYQUESTION.c_str();

	string TXT;
	int break_txt = 80;
	TXT = CONF.TXT;

	string format;	
	if(CONF.FORMAT == "large")
	{	
		format = "large";
	}
	else
	{	
		format = "topic";
	}


	// we check for valid values in class config! 
	// we maybe here at the last point of the program!

	db = new Database();

	// Initialise the database - for future releases
	if (db->init() != DB_COMMAND_OK) {
		fprintf(stdout, "Unable to initialize database: %s\n\n", 
		        db->errorMessage());
		exit(0);
        }

	// Connect to database on localhost
	if (db->connect(HOST, "", MYDATABASE, USER, PASS) != DB_CONNECTION_OK) { 
		fprintf(stdout, "Unable connect to database '%s': %s\n\n", 
		        MYDATABASE, db->errorMessage());
		exit(0);
	}
//cout << "debug2\n";
	int topic_max = 0, question_max;
	string *tmp, *question_id, *question; 
	tmp = new string[10];
	string temp, navbar;
	int answer_max;
	// determine the numer of rows in topic...	
	res = db->exec("SELECT topic_id FROM %s ", MYTOPIC);
	tuple = res->getTuple();
	while (tuple != NULL)
	{
		topic_max++;
		tuple = res->getTuple();
	}

	string topic[topic_max + 1];
	int topic_id[topic_max + 1];
	string topic_id_str[topic_max + 1];
	
	// now get the real topic_id's
	db->exec(res, "SELECT topic_id FROM %s ", MYTOPIC);
        tuple = res->getTuple();
	i=0;
        while (tuple != NULL)
        {
                topic_id[i] = atoi(*(tuple));
		topic_id_str[i] = *(tuple);
                tuple = res->getTuple();
		i++;
        }
	
	// get the related topics...
	db->exec(res, "SELECT value FROM %s ", MYTOPIC);
        tuple = res->getTuple();
        i = 0;
	while (tuple != NULL)
        {
                topic[i] = *(tuple);
                tuple = res->getTuple();
		i++;
        }
	string Head, Foot, Index_Temp_f, Index_Header_f, Index_Footer_f;
	string Store_answer[20], Store_tmp[20], topic_f, anchor;
	char ch;
	string TXT_f = string(PATH) + "/" + TXT;
	string TXT_t = string(PATH) + "/" + TXT + ".temp";
	ofstream INDEX_TXT(TXT_f.c_str());
	ofstream TXT_TMP(TXT_t.c_str());
	ifstream txt_t(TXT_t.c_str());
	Index_Header_f = string(PATH) + "/" + string(HEADER);
	Index_Footer_f = string(PATH) + "/" + string(FOOTER);
	Index_Temp_f = string(PATH) + "/temp.html"; 
	ofstream Index_Temp(Index_Temp_f.c_str());
	ifstream Header_File(Index_Header_f.c_str());
	ifstream Footer_File(Index_Footer_f.c_str());
	if( !Header_File )
	{
		Head = h.html() + h.body("#ffffff", "#000000", "#3333FF", "#3333FF", "#FF0000");
		Head += h.title("Database Full Index") + "<p></p>\n";
	}
	else
	{
		while( Header_File )
		{
			Header_File.get(ch);
			Head += ch;
		}
	}
	if( !Footer_File )
	{
		Foot = "<font size=1>created by faq-system " + string(VERSION); 
		Foot += " <a href=mailto:" + string(AUTOR_MAIL) + ">" + string(AUTOR) + "</a></font>" + h._body() + h._html() + "\n";
	}
	else
	{
		while( Footer_File )
		{ 
			Footer_File.get(ch);
			Foot += ch;
		}
	}
	// ################ fullindex.html ########################
        string Index_Name = string(PATH) + "/" + instance + ".html";
        ofstream Index(Index_Name.c_str());
	Index << Head;
	Index << "<a name=\"top\"></a>\n";
	Index << "<h2>Table of Contents</h2>\n";
	Index << "<p><hr></p>";

	if(TXT != "")
		INDEX_TXT << "TABLE OF CONTENTS\n\n";
	

	cout << h.html()
		<< h.body("#ffffff", "#000000", "#3333FF", "#3333FF", "#FF0000");
	cout    << "<p>" << h.font("arial", "2");
	cout	<< "<A HREF=\"" << URL << "/" << ADMIN << "/index.cgi?instance=" << instance << "\">[ reload site ]</A> ";
	cout << "<A HREF=\"" << URL << "/search.cgi?instance=" << instance << "&stage=prepare\">[ search ]</A> ";
	cout << "<A HREF=\"" << HTTP_BASE << "/" << instance << ".html\">[ full index ]</A> ";
	if(TXT != "")
		cout << "<A HREF=\"" << HTTP_BASE << "/" << TXT << "\">[ " << TXT << "]</A> ";
	cout << "<A HREF=\"" << HTTP_BASE << "/" ADMIN << "/help.html\">[ help ]</A> ";
	cout  << "</p>" << h._font(); 
	cout	<< "<p>" << h.font("arial", "+2"); 
	cout	<< "<b>  Topics  </b>" <<  h._font();
	cout	<< h.font("arial", "1") ;
	cout	<< "&nbsp;&nbsp;<A HREF=\"" << URL << "/" << ADMIN << "/topic.cgi?instance=" << instance; 
	cout	<< "&stage=prepare\">[ new topic ]</A></p>" << endl;
	for(int t=0;t<topic_max;t++)
	{
	if(format == "large")
	{
		// create an Index Entry
		Index << "<b>" << topic_id[t] << ". " << topic[t] << "</b><br>\n<ul>\n";
	}
	else
    	{
		// create one file per topic...
		Index << "<a href=\"" << instance << "_topic_" << topic_id[t] << ".html\"><b>" 
		<< topic_id[t] << ". " << topic[t] << "</b></a><br>\n<ul>\n";
	}
		topic_f = string(PATH) + "/" + instance + "_topic_" + topic_id_str[t] + ".html";
		ofstream topic_file(topic_f.c_str());
	if(TXT != "")
	{
                        INDEX_TXT << topic_id[t] << ". " << topic[t] << "\n";
			TXT_TMP << "\n\n" << topic_id[t] << ". " << topic[t] << "\n\n";
	}
	if(format == "topic")
	{
		topic_file << Head;
		topic_file << "<a name=\"top\"></a>\n";
		
		navbar = "";
		navbar += "<a href=\"" + instance + ".html\">[ top ]</a> ";
		if(t == 0)
                {
                        navbar += "<a href=\"" + instance + "_topic_" + topic_id_str[t+1] + ".html\">[ next ]</a> ";
                }
                else if(t == topic_max)
                {
                        navbar += "<a href=\"" + instance + "_topic_" + topic_id_str[t-1] + ".html\">[ previous ]</a> ";
                }
                else
                {
                        navbar += "<a href=\"" + instance + "_topic_" + topic_id_str[t-1] + ".html\">[ previous ]</a> ";
                        navbar += "<a href=\"" + instance + "_topic_" + topic_id_str[t+1] + ".html\">[ next ]</a> ";
                }
 		
		topic_file << navbar;
		topic_file << "\n<br></br><h1>" << topic[t] << "</h1><br></br>\n";
	 
	}		
		
		cout 	<< "<p><b>" << h.font("arial", "3") << topic_id[t] << ". "; 
		cout	<< topic[t] << h._font();
		cout	<< h.font("arial", "1") << "&nbsp;&nbsp;<A HREF=\"" << URL ;
		cout	<< "/" << ADMIN << "/question.cgi?instance=" << instance << "&stage=prepare&topic_id="; 
		cout	<< topic_id[t] << "\">[ ask ]</A> "; 
		cout	<< "<A HREF=\"" << URL << "/" << ADMIN << "/modify.cgi?instance=" << instance 
			<< "&stage=prepare&mode=topic&topic_id="; 
		cout 	<< topic_id[t] << "\">[ modify ]</A>" << h._font(); 
		cout	<< h._font();
		cout	<< "</b></p>\n";
		db->exec(res, "SELECT question_id FROM %s WHERE topic_id = %d", MYQUESTION, topic_id[t]);
        	tuple = res->getTuple();
		question_max = 0;
       		while (tuple != NULL)
        	{
                       	question_max++; 
                	tuple = res->getTuple();
		}
		//cout << "debug IV\n";	
		question = new string[question_max];
		question_id = new string[question_max];

		db->exec(res, "SELECT value FROM %s WHERE topic_id = %d ", MYQUESTION, topic_id[t]);
                tuple = res->getTuple();
		i=0;
                while (tuple != NULL)
                {
                        question[i] = *(tuple);
			tuple = res->getTuple();
			i++;
                }
		db->exec(res, "SELECT question_id FROM %s WHERE topic_id = %d ", MYQUESTION, topic_id[t]);
                tuple = res->getTuple();
		i=0;
                while (tuple != NULL)
                {
			question_id[i] = *(tuple);
                        tuple = res->getTuple();
                        i++;
                }	

		for(int b=0; b<question_max; b++)
		{
			db->exec(res, "SELECT value FROM %s WHERE question_id = %s", MYANSWER, question_id[b].c_str());
			tuple = res->getTuple();
			answer_max = 0;
			while (tuple != NULL)	
			{
				if( *(tuple) == NULL)
				{
					answer_max=0;
					break;
				}
				answer_max++;
				tuple = res->getTuple();
			}

			cout << h.font("arial", "2") << endl; 
			cout << "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
			if( answer_max != 0 )
			{
				// create anchor name
				i=0;
				db->exec(res, "SELECT value FROM %s WHERE question_id = %s", MYANSWER, question_id[b].c_str());
                                tuple = res->getTuple();
				int p;
				string produce, store, store_txt, link, caption;
				//char *link, *caption;
				//link = new char[250];
				//caption = new char[250];
				while (tuple != NULL)
                                {
                                        temp = *(tuple);
					int length = temp.length();
					for(int pos=0; pos<length;pos++)
					{
						if(temp[pos] == '#')
						{
							if(temp[pos+1] == '#')
							{
								pos += 2;
								p=0;
								while(temp[pos] != '#')
								{
									link += temp[pos];
									p++;
									pos++;
								} 
								pos++;
								p=0;
								while(temp[pos] != '#')
								{
									caption += temp[pos];
									p++;
									pos++;
								}
								if(TXT != "")
                                                                        store_txt += caption + " " + link;		
								store += "<a href=\"";
								if(link[0] == '_')
								{
									string topic_link;
									int topic_link_pos = 0;
									int topic_link_len = link.length();
									for(int p=0;p<topic_link_len;p++)
									{
										if(link[p] == '_')
										{
											if(topic_link_pos == 0)
												topic_link_pos++;
										}
										else
										{
											if(topic_link_pos == 1)
											{		
												topic_link += link[p];
												if(link[p+1] == '_')
													topic_link_pos++;
											}
										}
									}		
									store += string(HTTP_BASE) + "/";
		  							if(format == "large")
										store += instance + ".html#";
  									else
										//store += instance + "_topic_" + topic_id_str[t] + ".html#";
										store += instance + "_topic_" + topic_link + ".html#";
 
								}
								store += link + "\">" + caption + "</a>";
								link = "";
								caption = "";	
							}
							else
							{
								store += temp[pos];
								store_txt += temp[pos];
								if(pos == break_txt)
									store_txt += "\n";
							}
						}
						else
						{
							store += temp[pos];
							store_txt += temp[pos];
							if(pos == break_txt)
                                                                        store_txt += "\n";
						}
					}
					Store_tmp[i] = store_txt;
					Store_answer[i] = store;
					store = "";	         
					store_txt = "";               		 
                                        tuple = res->getTuple();
                                        i++;
                                } 
				Index << "<li>"; 
				if(format == "large")
				{
					Index << "<a href=\"#_" << topic_id[t] << "_" << b
					<< "\">" << topic_id[t] << "." << b << ". " << question[b] << "</a><br>\n";


					Index_Temp << "<a name=\"_" << topic_id[t] << "_" << b  << "\"></a>\n";
					Index_Temp << "<h3>" << topic_id[t] << "." << b << ". " << question[b] << "</h3>\n";


					// here comes the answer:
					for(int m=0;m<i;m++)
					{
						Index_Temp << Store_answer[m].c_str() << "<br></br>\n";
					}
					Index_Temp << endl << "<br>" << h.font("arial", "1") 
					<< "<br></br><p><a href=\"#top\">[ top ]</a></p>"
					<< h._font() <<"<p></p><hr><p></p><br>" << endl;
				}
				else
				{
					Index << "<a href=\"" << instance << "_topic_" << topic_id[t] << ".html#_"
					<< topic_id[t] << "_" << b 
					<< "\">" << topic_id[t] << "." << b << ". " << question[b] << "</a><br>\n";	
					
					topic_file << "<a name=\"_" << topic_id[t] << "_" << b  << "\"></a>\n";
					topic_file << "<h3>" << topic_id[t] << "." << b << ". " << question[b] << "</h3>\n";
					// here comes the answer:
					for(int m=0;m<i;m++)
					{
						topic_file << Store_answer[m].c_str() << "<br></br>\n";
					} 
					topic_file << h.font("arial", "1") << "<br></br><p><a href=\"#top\">[ top ]</a></p>"
					<< h._font() << "<p></p><hr><p></p>\n";
				}
				
				if(TXT != "")
                                {
                                        TXT_TMP << "    " << topic_id[t] << "." << b << ". " << question[b] << "\n\n";
                                        INDEX_TXT << "	" << topic_id[t] << "." << b << ". " << question[b] << "\n";
					for(int m=0;m<i;m++)
						TXT_TMP << Store_tmp[m].c_str() << "\n\n\n";
                                }
				cout << "<A HREF=\"" << URL 
 				<< "/getanswer.cgi?instance=" << instance << "&stage=dbadmin&question_id=";  
				cout << question_id[b] << "\">" << topic_id[t] << "." << b << ". ";
				cout << "<b>" << question[b] << "</b>";
				cout << "</A><b>" << h.font("arial","1") 
				<< " [[ _" << topic_id[t] << "_" << b << " ]]" << h._font() << "</b>";
				cout << "</A>";
			}
			else
			{

				cout << topic_id[t] << "." << b << ". ";
				cout << "<b>" << question[b] << "</b>";
			}

			cout << h._font();
			cout << h.font("arial","1") << "&nbsp;&nbsp;<A HREF=\"" << URL 
			<< "/" << ADMIN << "/answer.cgi?instance=" << instance << "&stage=prepare&question_id=";
			cout << question_id[b] << "&topic_id=" << topic_id[t];
			cout << "\">[ answer ]</A> ";
			cout << " <A HREF=\"" << URL << "/" << ADMIN << "/modify.cgi?instance=" << instance 
				<< "&stage=prepare&mode=question&question_id=";
			cout << question_id[b] << "&topic_id=" << topic_id[t];
			cout << "\">[ modify ]</A>" << h._font();
			cout << "<br>" << endl; 
		} 
		Index << "</ul>\n";
		if(TXT != "")
			INDEX_TXT << "\n";

		topic_file << "</ul>\n"; 
		if(format == "topic")
		{
			topic_file << "<P></P>" << navbar;
			topic_file << "<br></br>" << Foot;
		}	
		cout << "<P></P><br></br>";		
	}
	if(format == "large")
	{
		Index << "<p></p><p></p><hr><p></p><p></p>\n";
		char buffer[1000];
		ifstream f(Index_Temp_f.c_str());
		while ( f )
		{
			f.getline(buffer, 1000);
			Index << buffer << "\n";
		}
	}
	if(TXT != "")
	{
		TXT_TMP.close();
		INDEX_TXT << "\n\n\n\n";
		char buf[1000];
		//ifstream txt_t(TXT_t.c_str());
		while ( txt_t )
		{
			txt_t.getline(buf, 1000);
			INDEX_TXT << buf << "\n";
		}
		INDEX_TXT << "\n\n\ncreated by faq-system " << VERSION << "\n";
	}
	Index << Foot;	
	cout << "<p><font size=1>faq-system " << VERSION << " . &copy; 1999 Thomas Linden</font></p>";
	cout << h._body() << h._html();
	
	delete res;			// Drop buffer
	delete db;			// Close connection
}
